aboutsummaryrefslogtreecommitdiff
path: root/include/libbb.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/libbb.h')
-rw-r--r--include/libbb.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/libbb.h b/include/libbb.h
index ad1c7346f..c7e830c09 100644
--- a/include/libbb.h
+++ b/include/libbb.h
@@ -1408,11 +1408,11 @@ extern int set_loop(char **devname, const char *file, unsigned long long offset,
#define BB_LO_FLAGS_READ_ONLY 1
#define BB_LO_FLAGS_AUTOCLEAR 4
-/* Like bb_ask below, but asks on stdin with no timeout. */
-char *bb_ask_stdin(const char * prompt) FAST_FUNC;
+/* Like bb_ask_noecho below, but asks on stdin with no timeout. */
+char *bb_ask_noecho_stdin(const char *prompt) FAST_FUNC;
//TODO: pass buf pointer or return allocated buf (avoid statics)?
-char *bb_ask(const int fd, int timeout, const char * prompt) FAST_FUNC;
-int bb_ask_confirmation(void) FAST_FUNC;
+char *bb_ask_noecho(const int fd, int timeout, const char *prompt) FAST_FUNC;
+int bb_ask_y_confirmation(void) FAST_FUNC;
/* Returns -1 if input is invalid. current_mode is a base for e.g. "u+rw" */
int bb_parse_mode(const char* s, unsigned cur_mode) FAST_FUNC;